onAttachFile property
An optional callback to trigger when the attach file button is pressed. If null, the button will not be displayed.
Implementation
final VoidCallback? onAttachFile;
An optional callback to trigger when the attach file button is pressed. If null, the button will not be displayed.
final VoidCallback? onAttachFile;